@@ -542,8 +542,8 @@ class Model(_BaseGeometry):
             feature_dict['properties']['floor_area'] = bldg.floor_area
             feature_dict['properties']['footprint_area'] = \
                 sum((face.area for face in footprint))
-            feature_dict['properties']['id'] = str(i + 1)
-            feature_dict['properties']['name'] = bldg.name
+            feature_dict['properties']['id'] = bldg.name
+            feature_dict['properties']['name'] = bldg.display_name
             feature_dict['properties']['number_of_stories'] = bldg.story_count
             feature_dict['properties']['type'] = 'Building'
             feature_dict['properties']['detailed_model_filename'] = \
@@ -621,6 +621,12 @@ class Model(_BaseGeometry):
                 [shd.to_dict(True, included_prop) for shd in self._context_shades]
         if self.north_angle != 0:
             base['north_angle'] = self.north_angle
+        if self.units != 'Meters':
+            base['units'] = self.units
+        if self.tolerance != 0:
+            base['tolerance'] = self.tolerance
+        if self.angle_tolerance != 0:
+            base['angle_tolerance'] = self.angle_tolerance
 
         return base
 
