@@ -19,6 +19,7 @@ from ladybug_geometry.geometry3d.plane import Plane
 from ladybug_geometry.geometry3d.face import Face3D
 from ladybug.futil import nukedir
 
+import json
 import os
 
 
@@ -473,6 +474,8 @@ def test_to_dict():
 
     model = Model('New Development', [building], [tree_canopy])
     model.north_angle = 15
+    model.tolerance = 0.01
+    model.angle_tolerance = 1
 
     model_dict = model.to_dict()
     assert model_dict['type'] == 'Model'
@@ -484,6 +487,10 @@ def test_to_dict():
     assert len(model_dict['context_shades']) == 1
     assert 'north_angle' in model_dict
     assert model_dict['north_angle'] == 15
+    assert 'tolerance' in model_dict
+    assert model_dict['tolerance'] == 0.01
+    assert 'angle_tolerance' in model_dict
+    assert model_dict['angle_tolerance'] == 1
     assert 'properties' in model_dict
     assert model_dict['properties']['type'] == 'ModelProperties'
 
@@ -516,6 +523,16 @@ def test_to_from_dict_methods():
     assert model_dict == new_model.to_dict()
 
 
+def test_from_dict_nulls():
+    """Test the re-serialization of a Model with null extension properties."""
+    test_json = './tests/json/model_with_nulls.json'
+    with open(test_json) as json_file:
+        data = json.load(json_file)
+    model = Model.from_dict(data)
+
+    assert isinstance(model, Model)
+
+
 def test_to_geojson():
     """Test the Model to_geojson method."""
     pts_1 = (Point3D(50, 50, 3), Point3D(60, 50, 3), Point3D(60, 60, 3), Point3D(50, 60, 3))
